@@ -40,7 +40,7 @@ Log::Log(gameTableImpl* w, ConfigFile *c) : myW(w), myConfig(c), myLogDir(0), my
 	connect(this, SIGNAL(signalLogPlayerSitsOut(QString)), this, SLOT(logPlayerSitsOut(QString)));
 	connect(this, SIGNAL(signalLogDealBoardCardsMsg(int, int, int, int, int, int)), this, SLOT(logDealBoardCardsMsg(int, int, int, int, int, int)));
 	connect(this, SIGNAL(signalLogFlipHoleCardsMsg(QString, int, int, int, QString)), this, SLOT(logFlipHoleCardsMsg(QString, int, int, int, QString)));
-	connect(this, SIGNAL(signalLogPlayerLeftMsg(QString)), this, SLOT(logPlayerLeftMsg(QString)));
+	connect(this, SIGNAL(signalLogPlayerLeftMsg(QString, int)), this, SLOT(logPlayerLeftMsg(QString, int)));
 	connect(this, SIGNAL(signalLogNewGameAdminMsg(QString)), this, SLOT(logNewGameAdminMsg(QString)));
 	connect(this, SIGNAL(signalLogPlayerWinGame(QString, int)), this, SLOT(logPlayerWinGame(QString, int))); 
 	connect(this, SIGNAL(signalFlushLogAtGame(int)), this, SLOT(flushLogAtGame(int))); 
@@ -151,7 +151,7 @@ void Log::logPlayerActionMsg(QString msg, int action, int setValue) {
 void Log::logNewGameHandMsg(int gameID, int handID) {
 
 	PlayerListConstIterator it_c;
-	HandInterface *currentHand = myW->getSession().getCurrentGame()->getCurrentHand();
+	HandInterface *currentHand = myW->getSession()->getCurrentGame()->getCurrentHand();
 
 	myW->textBrowser_Log->append("<span style=\"font-size:large; font-weight:bold\">## Game: "+QString::number(gameID,10)+" | Hand: "+QString::number(handID,10)+" ##</span>");
 
@@ -183,7 +183,7 @@ void Log::logNewBlindsSetsMsg(int sbSet, int bbSet, QString sbName, QString bbNa
 	myW->textBrowser_Log->append("<span>"+bbName+" posts big blind ($"+QString::number(bbSet,10)+")</span>");
 
 	PlayerListConstIterator it_c;
-	HandInterface *currentHand = myW->getSession().getCurrentGame()->getCurrentHand();
+	HandInterface *currentHand = myW->getSession()->getCurrentGame()->getCurrentHand();
 	for(it_c=currentHand->getActivePlayerList()->begin(); it_c!=currentHand->getActivePlayerList()->end(); it_c++) {
 		if(currentHand->getActivePlayerList()->size() > 2) {
 			if((*it_c)->getMyButton() == BUTTON_DEALER) {
@@ -323,13 +323,17 @@ void Log::logFlipHoleCardsMsg(QString playerName, int card1, int card2, int card
 	
 }
 
-void Log::logPlayerLeftMsg(QString playerName) {
+void Log::logPlayerLeftMsg(QString playerName, int wasKicked) {
 
-	myW->textBrowser_Log->append( "<i>"+playerName+" has left the game!</i>");
+	QString action;
+	if(wasKicked) action = "was kicked from";
+	else action = "has left";
+
+	myW->textBrowser_Log->append( "<i>"+playerName+" "+action+" the game!</i>");
 	
 	if(myConfig->readConfigInt("LogOnOff")) {
 	
-		logFileStreamString += "<i>"+playerName+" has left the game!</i><br>\n";
+		logFileStreamString += "<i>"+playerName+" "+action+" the game!</i><br>\n";
 
 		if(myConfig->readConfigInt("LogInterval") == 0) {	
 			writeLogFileStream(logFileStreamString);
@@ -1237,7 +1241,7 @@ QString Log::determineHandName(int myCardsValueInt) {
 	list<int> sameHandCardsValueInt;
 	bool different = false;
 	bool equal = false;
-	HandInterface *currentHand = myW->getSession().getCurrentGame()->getCurrentHand();
+	HandInterface *currentHand = myW->getSession()->getCurrentGame()->getCurrentHand();
 	PlayerListConstIterator it_c;
 
 	// collect cardsValueInt of all players who will show their cards
@@ -1651,18 +1655,23 @@ void Log::writeLogFileStream(QString streamString) {
 
 void Log::flushLogAtHand() { 	
 
-	if(myConfig->readConfigInt("LogInterval") < 2) {
-// 	write for log after every action and after every hand
-		writeLogFileStream(logFileStreamString);
-		logFileStreamString = "";
+	if(myConfig->readConfigInt("LogOnOff")) {
+		if(myConfig->readConfigInt("LogInterval") < 2) {
+	// 	write for log after every action and after every hand
+			writeLogFileStream(logFileStreamString);
+			logFileStreamString = "";
+		}
 	}
 }
 
-void Log::flushLogAtGame(int gameID) { 	
-//	write for log after every game
-	if(gameID > lastGameID) {
-		writeLogFileStream(logFileStreamString);
-		logFileStreamString = "";
-		lastGameID = gameID;
+void Log::flushLogAtGame(int gameID) {
+
+	if(myConfig->readConfigInt("LogOnOff")) { 	
+	//	write for log after every game
+		if(gameID > lastGameID) {
+			writeLogFileStream(logFileStreamString);
+			logFileStreamString = "";
+			lastGameID = gameID;
+		}
 	}
 }
