@@ -253,6 +253,32 @@ ClientThread::SendResetTimeout()
 	m_outPacketList.push_back(reset);	
 }
 
+void
+ClientThread::SendAskKickPlayer(unsigned playerId)
+{
+	boost::shared_ptr<NetPacket> ask(new NetPacketAskKickPlayer);
+	NetPacketAskKickPlayer::Data askData;
+	askData.playerId = playerId;
+	static_cast<NetPacketAskKickPlayer *>(ask.get())->SetData(askData);
+	boost::mutex::scoped_lock lock(m_outPacketListMutex);
+	m_outPacketList.push_back(ask);
+}
+
+void
+ClientThread::SendVoteKick(bool doKick)
+{
+	boost::shared_ptr<NetPacket> vote(new NetPacketVoteKickPlayer);
+	NetPacketVoteKickPlayer::Data voteData;
+	{
+		boost::mutex::scoped_lock lock(m_curPetitionIdMutex);
+		voteData.petitionId = m_curPetitionId;
+	}
+	voteData.vote = doKick ? KICK_VOTE_IN_FAVOUR : KICK_VOTE_AGAINST;
+	static_cast<NetPacketVoteKickPlayer *>(vote.get())->SetData(voteData);
+	boost::mutex::scoped_lock lock(m_outPacketListMutex);
+	m_outPacketList.push_back(vote);
+}
+
 GameInfo
 ClientThread::GetGameInfo(unsigned gameId) const
 {
@@ -739,7 +765,7 @@ ClientThread::AddPlayerData(boost::shared_ptr<PlayerData> playerData)
 }
 
 void
-ClientThread::RemovePlayerData(unsigned playerId)
+ClientThread::RemovePlayerData(unsigned playerId, int removeReason)
 {
 	boost::shared_ptr<PlayerData> tmpData;
 
@@ -759,7 +785,7 @@ ClientThread::RemovePlayerData(unsigned playerId)
 	if (tmpData.get())
 	{
 		// Remove player from gui.
-		GetCallback().SignalNetClientPlayerLeft(tmpData->GetUniqueId(), tmpData->GetName());
+		GetCallback().SignalNetClientPlayerLeft(tmpData->GetUniqueId(), tmpData->GetName(), removeReason);
 	}
 }
 
@@ -996,6 +1022,47 @@ ClientThread::ClearGameInfoMap()
 	m_gameInfoMap.clear();
 }
 
+void
+ClientThread::StartPetition(unsigned petitionId, unsigned proposingPlayerId, unsigned kickPlayerId, int timeoutSec, int numVotesToKick)
+{
+	{
+		boost::mutex::scoped_lock lock(m_curPetitionIdMutex);
+		m_curPetitionId = petitionId;
+	}
+	GetGui().startVoteOnKick(kickPlayerId, proposingPlayerId, timeoutSec, numVotesToKick);
+	if (GetGuiPlayerId() != kickPlayerId
+		&& GetGuiPlayerId() != proposingPlayerId)
+	{
+		GetGui().changeVoteOnKickButtonsState(true);
+	}
+}
+
+void
+ClientThread::UpdatePetition(unsigned petitionId, int /*numVotesAgainstKicking*/, int numVotesInFavourOfKicking, int numVotesToKick)
+{
+	bool isCurPetition;
+	{
+		boost::mutex::scoped_lock lock(m_curPetitionIdMutex);
+		isCurPetition = m_curPetitionId == petitionId;
+	}
+	if (isCurPetition)
+	{
+		GetGui().refreshVotesMonitor(numVotesInFavourOfKicking, numVotesToKick);
+	}
+}
+
+void
+ClientThread::EndPetition(unsigned petitionId)
+{
+	bool isCurPetition;
+	{
+		boost::mutex::scoped_lock lock(m_curPetitionIdMutex);
+		isCurPetition = m_curPetitionId == petitionId;
+	}
+	if (isCurPetition)
+		GetGui().endVoteOnKick();
+}
+
 void
 ClientThread::UpdateStatData(const ServerStats &stats)
 {
